.. :changelog:

History
-------

0.2.0 (2018-10-31)
++++++++++++++++++

* Better infrastructure (type annotations, documentation, ...)
* Dropped support for Python 2.
* New function: update_observation()
* rest_api.AuthenticationError is now exceptions.AuthenticationError


0.1.0 (2018-10-10)
++++++++++++++++++

* First release on PyPI.
